<?php

namespace Bixo\Product\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Product\Actions\DescriptionAction;
use Bixo\Product\Http\Requests\DescriptionActionRequest;
use Bixo\Product\Http\Resources\DescriptionResource;
use Bixo\Product\Models\Description;

/**
 * Admin web controller class.
 */
class DescriptionActionController extends BaseController
{

    /**
     * Action controller function for description.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(DescriptionActionRequest $request, Description $description, $action)
    {
        try {
            $request = $request->all();
            $description = DescriptionAction::run($action, $description, $request);

            $data = new DescriptionResource($description);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('product::description.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('product/description/' . $description->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('product/description/' . $description->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
