<?php

namespace Bixo\Product\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Product\Actions\PortalAction;
use Bixo\Product\Http\Requests\PortalActionRequest;
use Bixo\Product\Http\Resources\PortalResource;
use Bixo\Product\Models\Portal;

/**
 * Admin web controller class.
 */
class PortalActionController extends BaseController
{

    /**
     * Action controller function for portal.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(PortalActionRequest $request, Portal $portal, $action)
    {
        try {
            $request = $request->all();
            $portal = PortalAction::run($action, $portal, $request);

            $data = new PortalResource($portal);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('product::portal.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('product/portal/' . $portal->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('product/portal/' . $portal->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
