<?php

namespace Bixo\Product\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Product\Actions\PropertyReport;
use Bixo\Product\Http\Requests\PropertyReportRequest;

/**
 * Admin web controller class.
 */
class PropertyReportController extends BaseController
{
    /**
     * Action controller function for property.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(PropertyReportRequest $request, $report)
    {
        try {
        
            $this->model = app(Property::class);
            $data = PropertyReport::run($request, $report);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('product::property.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('product/property/' . $report))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('product/property/' . $report))
                ->redirect();
        }
    }
}
