<?php

namespace Bixo\Product\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Product\Events\DescriptionAction as DescriptionActionEvent;
use Bixo\Product\Notifications\DescriptionAction as DescriptionActionNotification;
use Litepie\Actions\Concerns\AsAction;

class DescriptionAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the DescriptionActionEvent.
     *
     * @param   DescriptionActionEvent  $event
     * @return mixed
     */
    public function handle(DescriptionActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $description.
     *
     * @param   DescriptionActionEvent  $event
     * @return void
     */
    public function create(DescriptionActionEvent $event)
    {
        $client = $event->description->client;
        Notification::send($client, new DescriptionActionNotification($event));
    }

    /**
     * Handle the DescriptionActionEvent as a listener.
     *
     * @param   DescriptionActionEvent  $event
     * @return mixed
     */
    public function asListener(DescriptionActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   DescriptionActionEvent  $event
     * @return bool
     */
    private function isAllowed(DescriptionActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
