<?php

namespace Bixo\Product\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Product\Events\DescriptionWorkflow as DescriptionWorkflowEvent;
use Bixo\Product\Notifications\DescriptionWorkflow as DescriptionWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class DescriptionWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(DescriptionWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $description is submitted.
     *
     * @param DescriptionWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(DescriptionWorkflowEvent $event)
    {
        $client = $event->description->client;
        Notification::send($client, new DescriptionWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $description is published.
     *
     * @param DescriptionWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(DescriptionWorkflowEvent $event)
    {
        $client = $event->description->client;
        Notification::send($client, new DescriptionWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $description is approved.
     *
     * @param DescriptionWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(DescriptionWorkflowEvent $event)
    {
        $client = $event->description->client;
        Notification::send($client, new DescriptionWorkflowNotification($event));
    }

    /**
     * Handles the $description workflow event as a listener.
     *
     * @param DescriptionWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(DescriptionWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
