<?php

namespace Bixo\Product\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Product\Events\PortalAction as PortalActionEvent;
use Bixo\Product\Notifications\PortalAction as PortalActionNotification;
use Litepie\Actions\Concerns\AsAction;

class PortalAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the PortalActionEvent.
     *
     * @param   PortalActionEvent  $event
     * @return mixed
     */
    public function handle(PortalActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $portal.
     *
     * @param   PortalActionEvent  $event
     * @return void
     */
    public function create(PortalActionEvent $event)
    {
        $client = $event->portal->client;
        Notification::send($client, new PortalActionNotification($event));
    }

    /**
     * Handle the PortalActionEvent as a listener.
     *
     * @param   PortalActionEvent  $event
     * @return mixed
     */
    public function asListener(PortalActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   PortalActionEvent  $event
     * @return bool
     */
    private function isAllowed(PortalActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
