<?php

namespace Bixo\Product\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Product\Events\PortalWorkflow as PortalWorkflowEvent;
use Bixo\Product\Notifications\PortalWorkflow as PortalWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class PortalWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(PortalWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $portal is submitted.
     *
     * @param PortalWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(PortalWorkflowEvent $event)
    {
        $client = $event->portal->client;
        Notification::send($client, new PortalWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $portal is published.
     *
     * @param PortalWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(PortalWorkflowEvent $event)
    {
        $client = $event->portal->client;
        Notification::send($client, new PortalWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $portal is approved.
     *
     * @param PortalWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(PortalWorkflowEvent $event)
    {
        $client = $event->portal->client;
        Notification::send($client, new PortalWorkflowNotification($event));
    }

    /**
     * Handles the $portal workflow event as a listener.
     *
     * @param PortalWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(PortalWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
