<?php

namespace Bixo\Product\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Product\Events\PropertyWorkflow as PropertyWorkflowEvent;
use Bixo\Product\Notifications\PropertyWorkflow as PropertyWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class PropertyWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(PropertyWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $property is submitted.
     *
     * @param PropertyWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(PropertyWorkflowEvent $event)
    {
        $client = $event->property->client;
        Notification::send($client, new PropertyWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $property is published.
     *
     * @param PropertyWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(PropertyWorkflowEvent $event)
    {
        $client = $event->property->client;
        Notification::send($client, new PropertyWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $property is approved.
     *
     * @param PropertyWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(PropertyWorkflowEvent $event)
    {
        $client = $event->property->client;
        Notification::send($client, new PropertyWorkflowNotification($event));
    }

    /**
     * Handles the $property workflow event as a listener.
     *
     * @param PropertyWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(PropertyWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
