<?php
namespace Bixo\Product\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Product\Events\DescriptionAction as DescriptionActionEvent;
use Bixo\Product\Models\Description;

class DescriptionAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $description;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param DescriptionActionEvent $description
     */
    public function __construct(DescriptionActionEvent $description)
    {
        $this->action = $event->action;
        $this->description = $description;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Description Approved - ' . config('app.name'))
            ->view('product::description.email.action', ['data' => $this->description]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
