<?php
namespace Bixo\Product\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Product\Events\PortalAction as PortalActionEvent;
use Bixo\Product\Models\Portal;

class PortalAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $portal;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param PortalActionEvent $portal
     */
    public function __construct(PortalActionEvent $portal)
    {
        $this->action = $event->action;
        $this->portal = $portal;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Portal Approved - ' . config('app.name'))
            ->view('product::portal.email.action', ['data' => $this->portal]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
