<?php
namespace Bixo\Product\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Product\Events\PropertyAction as PropertyActionEvent;
use Bixo\Product\Models\Property;

class PropertyAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $property;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param PropertyActionEvent $property
     */
    public function __construct(PropertyActionEvent $property)
    {
        $this->action = $event->action;
        $this->property = $property;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Property Approved - ' . config('app.name'))
            ->view('product::property.email.action', ['data' => $this->property]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
