<?php

namespace Bixo\Product\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Product\Models\Description;

class DescriptionPolicy
{

    use DescriptionAction;
    use DescriptionReport;
    use DescriptionWorkflow;

    /**
     * Determine if the given user can view the description.
     *
     * @param Authenticatable $user
     * @param Description $description
     *
     * @return bool
     */
    public function view(Authenticatable $user, Description $description)
    {
        if ($authUser->canDo('product.description.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $description->is_owner;
    }

    /**
     * Determine if the given user can create a description.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('product.description.create');
    }

    /**
     * Determine if the given user can update the given description.
     *
     * @param Authenticatable $user
     * @param Description $description
     *
     * @return bool
     */
    public function update(Authenticatable $user, Description $description)
    {
        if ($user->canDo('product.description.edit') && $user->isAdmin()) {
            return true;
        }

        return $description->is_owner;
    }

    /**
     * Determine if the given user can delete the given description.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Description $description)
    {
        return $description->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
