<?php

namespace Bixo\Product\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Product\Models\Portal;

class PortalPolicy
{

    use PortalAction;

    /**
     * Determine if the given user can view the portal.
     *
     * @param Authenticatable $user
     * @param Portal $portal
     *
     * @return bool
     */
    public function view(Authenticatable $user, Portal $portal)
    {
        if ($authUser->canDo('product.portal.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $portal->is_owner;
    }

    /**
     * Determine if the given user can create a portal.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('product.portal.create');
    }

    /**
     * Determine if the given user can update the given portal.
     *
     * @param Authenticatable $user
     * @param Portal $portal
     *
     * @return bool
     */
    public function update(Authenticatable $user, Portal $portal)
    {
        if ($user->canDo('product.portal.edit') && $user->isAdmin()) {
            return true;
        }

        return $portal->is_owner;
    }

    /**
     * Determine if the given user can delete the given portal.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Portal $portal)
    {
        return $portal->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
