<?php

namespace Bixo\Product\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Product\Models\Property;

class PropertyPolicy
{

    use PropertyAction;
    use PropertyReport;
    use PropertyWorkflow;

    /**
     * Determine if the given user can view the property.
     *
     * @param Authenticatable $user
     * @param Property $property
     *
     * @return bool
     */
    public function view(Authenticatable $user, Property $property)
    {
        if ($authUser->canDo('product.property.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $property->is_owner;
    }

    /**
     * Determine if the given user can create a property.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('product.property.create');
    }

    /**
     * Determine if the given user can update the given property.
     *
     * @param Authenticatable $user
     * @param Property $property
     *
     * @return bool
     */
    public function update(Authenticatable $user, Property $property)
    {
        if ($user->canDo('product.property.edit') && $user->isAdmin()) {
            return true;
        }

        return $property->is_owner;
    }

    /**
     * Determine if the given user can delete the given property.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Property $property)
    {
        return $property->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
